pub fn read_and_mut<F>(
color: &str,
begin: &str,
again: &str,
f: F,
) -> Result<(), Error>Expand description
Implements a basic menu loop using an embedded Repline,
provided to the caller’s closure, f.
Repeatedly runs the provided closure on the input strings, obeying the closure’s Response. The closure may modify the state of the Repline, including taking additional input.
Captures and displays all user Errors.
Keybinds
Ctrl+Cexits the loopCtrl+Dclears the input, but runs the closure with the old input